@@ -4,10 +4,11 @@ User OAuth Authenticator and helper functions
 ---------------------------------------------
 
 This tool is an alternative to various online services that give you a user auth token.
+It provides non-server and server options.
 
-************
-Requirements
-************
+***************************************
+Requirements for non-server environment
+***************************************
 
 Since this tool opens a browser tab for the Twitch authentication, you can only use this tool on enviroments that can
 open a browser window and render the `<twitch.tv>`__ website.
@@ -15,6 +16,15 @@ open a browser window and render the `<twitch.tv>`__ website.
 For my authenticator you have to add the following URL as a "OAuth Redirect URL": :code:`http://localhost:17563`
 You can set that `here in your twitch dev dashboard <https://dev.twitch.tv/console>`__.
 
+***********************************
+Requirements for server environment
+***********************************
+
+You need the user code provided by Twitch when the user logs-in at the url returned by :code:`return_auth_url`.
+
+Create the UserAuthenticator with the URL of your webserver that will handle the redirect, and add it as a "OAuth Redirect URL"
+You can set that `here in your twitch dev dashboard <https://dev.twitch.tv/console>`__.
+
 ************
 Code example
 ************
@@ -47,7 +57,6 @@ from aiohttp import web
 import asyncio
 from threading import Thread
 from time import sleep
-from os import path
 import requests
 from concurrent.futures._base import CancelledError
 from logging import getLogger, Logger
@@ -120,17 +129,29 @@ def revoke_token(client_id: str, access_token: str) -> bool:
 class UserAuthenticator:
     """Simple to use client for the Twitch User authentication flow.
 
-       :param ~twitchAPI.twitch.Twitch twitch: A twitch instance
-       :param list[~twitchAPI.types.AuthScope] scopes: List of the desired Auth scopes
-       :param bool force_verify: If this is true, the user will always be prompted for authorization by twitch,
+        :param ~twitchAPI.twitch.Twitch twitch: A twitch instance
+        :param list[~twitchAPI.types.AuthScope] scopes: List of the desired Auth scopes
+        :param bool force_verify: If this is true, the user will always be prompted for authorization by twitch,
                     |default| :code:`False`
-
-        :var str url: The reachable URL that will be opened in the browser.
+        :param str url: The reachable URL that will be opened in the browser.
                     |default| :code:`http://localhost:17563`
+
         :var int port: The port that will be used. |default| :code:`17653`
         :var str host: the host the webserver will bind to. |default| :code:`0.0.0.0`
        """
 
+    __document: str = """<!DOCTYPE html>
+ <html lang="en">
+ <head>
+     <meta charset="UTF-8">
+     <title>pyTwitchAPI OAuth</title>
+ </head>
+ <body>
+     <h1>Thanks for Authenticating with pyTwitchAPI!</h1>
+ You may now close this page.
+ </body>
+ </html>"""
+
     __twitch: 'Twitch' = None
     port: int = 17563
     url: str = 'http://localhost:17563'
@@ -156,12 +177,14 @@ class UserAuthenticator:
     def __init__(self,
                  twitch: 'Twitch',
                  scopes: List[AuthScope],
-                 force_verify: bool = False):
+                 force_verify: bool = False,
+                 url: str = 'http://localhost:17563'):
         self.__twitch = twitch
         self.__client_id = twitch.app_id
         self.scopes = scopes
         self.force_verify = force_verify
         self.__logger = getLogger('twitchAPI.oauth')
+        self.url = url
 
     def __build_auth_url(self):
         params = {
@@ -225,32 +248,38 @@ class UserAuthenticator:
             return web.Response(status=400)
         if self.__callback_func is not None:
             self.__callback_func(self.__user_token)
-        fn = path.join(path.dirname(__file__), 'oauth.html')
-        fd = ''
-        with open(fn, 'r') as f:
-            fd = f.read()
-        return web.Response(text=fd, content_type='text/html')
+        return web.Response(text=self.__document, content_type='text/html')
+
+    def return_auth_url(self):
+        return self.__build_auth_url()
 
     def authenticate(self,
-                     callback_func=None):
+                     callback_func=None, user_token=None):
         """Start the user authentication flow\n
-        If callback_func is not set, authenticate will wait till the authentication process finnished and then return
+        If callback_func is not set, authenticate will wait till the authentication process finished and then return
         the access_token and the refresh_token
+        If user_token is set, it will be used instead of launching the webserver and opening the browser
 
-        :param callback_func: Function to call once the authentication finnished.
+        :param callback_func: Function to call once the authentication finished.
+        :param str user_token: Code obtained from twitch to request the access and refresh token.
         :return: None if callback_func is set, otherwise access_token and refresh_token
         :rtype: None or (str, str)
         """
         self.__callback_func = callback_func
-        self.__start()
-        # wait for the server to start up
-        while not self.__server_running:
-            sleep(0.01)
-        # open in browser
-        webbrowser.open(self.__build_auth_url(), new=2)
-        while self.__user_token is None:
-            sleep(0.01)
-        # now we need to actually get the correct token
+
+        if user_token is None:
+            self.__start()
+            # wait for the server to start up
+            while not self.__server_running:
+                sleep(0.01)
+            # open in browser
+            webbrowser.open(self.__build_auth_url(), new=2)
+            while self.__user_token is None:
+                sleep(0.01)
+            # now we need to actually get the correct token
+        else:
+            self.__user_token = user_token
+
         param = {
             'client_id': self.__client_id,
             'client_secret': self.__twitch.app_secret,
@@ -264,3 +293,5 @@ class UserAuthenticator:
         if callback_func is None:
             self.stop()
             return data['access_token'], data['refresh_token']
+        elif user_token is not None:
+            self.__callback_func(self.__user_token)
