@@ -2,13 +2,11 @@
 """Type Definitions"""
 
 from enum import Enum
+from typing_extensions import TypedDict
 
 
 class AnalyticsReportType(Enum):
     """Enum of all Analytics report types
-
-    :var V1:
-    :var V2:
     """
     V1 = 'overview_v1'
     V2 = 'overview_v2'
@@ -16,35 +14,6 @@ class AnalyticsReportType(Enum):
 
 class AuthScope(Enum):
     """Enum of Authentication scopes
-
-    :var ANALYTICS_READ_EXTENSION:
-    :var ANALYTICS_READ_GAMES:
-    :var BITS_READ:
-    :var CHANNEL_READ_SUBSCRIPTIONS:
-    :var CHANNEL_READ_STREAM_KEY:
-    :var CHANNEL_EDIT_COMMERCIAL:
-    :var CHANNEL_READ_HYPE_TRAIN:
-    :var CHANNEL_MANAGE_BROADCAST:
-    :var CHANNEL_READ_REDEMPTIONS:
-    :var CHANNEL_MANAGE_REDEMPTIONS:
-    :var CLIPS_EDIT:
-    :var USER_EDIT:
-    :var USER_EDIT_BROADCAST:
-    :var USER_READ_BROADCAST:
-    :var USER_READ_EMAIL:
-    :var USER_EDIT_FOLLOWS:
-    :var CHANNEL_MODERATE:
-    :var CHAT_EDIT:
-    :var CHAT_READ:
-    :var WHISPERS_READ:
-    :var WHISPERS_EDIT:
-    :var MODERATION_READ:
-    :var CHANNEL_SUBSCRIPTIONS:
-    :var CHANNEL_READ_EDITORS:
-    :var CHANNEL_MANAGE_VIDEOS:
-    :var USER_READ_BLOCKED_USERS:
-    :var USER_MANAGE_BLOCKED_USERS:
-    :var USER_READ_SUBSCRIPTIONS:
     """
     ANALYTICS_READ_EXTENSION = 'analytics:read:extensions'
     ANALYTICS_READ_GAMES = 'analytics:read:games'
@@ -74,14 +43,17 @@ class AuthScope(Enum):
     USER_READ_BLOCKED_USERS = 'user:read:blocked_users'
     USER_MANAGE_BLOCKED_USERS = 'user:manage:blocked_users'
     USER_READ_SUBSCRIPTIONS = 'user:read:subscriptions'
+    USER_READ_FOLLOWS = 'user:read:follows'
+    CHANNEL_READ_POLLS = 'channel:read:polls'
+    CHANNEL_MANAGE_POLLS = 'channel:manage:polls'
+    CHANNEL_READ_PREDICTIONS = 'channel:read:predictions'
+    CHANNEL_MANAGE_PREDICTIONS = 'channel:manage:predictions'
+    MODERATOR_MANAGE_AUTOMOD = 'moderator:manage:automod'
+    CHANNEL_MANAGE_SCHEDULE = 'channel:manage:channel'
 
 
 class ModerationEventType(Enum):
     """Enum of moderation event types
-
-    :var BAN:
-    :var UNBAN:
-    :var UNKNOWN:
     """
     BAN = 'moderation.user.ban'
     UNBAN = 'moderation.user.unban'
@@ -90,12 +62,6 @@ class ModerationEventType(Enum):
 
 class TimePeriod(Enum):
     """Enum of valid Time periods
-
-    :var ALL:
-    :var DAY:
-    :var WEEK:
-    :var MONTH:
-    :var YEAR:
     """
     ALL = 'all'
     DAY = 'day'
@@ -106,10 +72,6 @@ class TimePeriod(Enum):
 
 class SortMethod(Enum):
     """Enum of valid sort methods
-
-    :var TIME:
-    :var TRENDING:
-    :var VIEWS:
     """
     TIME = 'time'
     TRENDING = 'trending'
@@ -118,10 +80,6 @@ class SortMethod(Enum):
 
 class HypeTrainContributionMethod(Enum):
     """Enum of valid Hype Train contribution types
-
-    :var BITS:
-    :var SUBS:
-    :var UNKNOWN:
     """
 
     BITS = 'BITS'
@@ -131,12 +89,6 @@ class HypeTrainContributionMethod(Enum):
 
 class VideoType(Enum):
     """Enum of valid video types
-
-    :var ALL:
-    :var UPLOAD:
-    :var ARCHIVE:
-    :var HIGHLIGHT:
-    :var UNKNOWN:
     """
     ALL = 'all'
     UPLOAD = 'upload'
@@ -147,10 +99,6 @@ class VideoType(Enum):
 
 class AuthType(Enum):
     """Type of authentication required. Only internal use
-
-    :var NONE: No auth required
-    :var USER: User auth required
-    :var APP: app auth required
     """
     NONE = 0
     USER = 1
@@ -160,17 +108,6 @@ class AuthType(Enum):
 
 class CodeStatus(Enum):
     """Enum Code Status, see https://dev.twitch.tv/docs/api/reference#get-code-status for more documentation
-
-    :var SUCCESSFULLY_REDEEMED:
-    :var ALREADY_CLAIMED:
-    :var EXPIRED:
-    :var USER_NOT_ELIGIBLE:
-    :var NOT_FOUND:
-    :var INACTIVE:
-    :var UNUSED:
-    :var INCORRECT_FORMAT:
-    :var INTERNAL_ERROR:
-    :var UNKNOWN_VALUE:
     """
     SUCCESSFULLY_REDEEMED = 'SUCCESSFULLY_REDEEMED'
     ALREADY_CLAIMED = 'ALREADY_CLAIMED'
@@ -186,12 +123,6 @@ class CodeStatus(Enum):
 
 class PubSubResponseError(Enum):
     """
-    :var BAD_MESSAGE: message is malformed
-    :var BAD_AUTH: user auth token is invalid
-    :var SERVER: server error
-    :var BAD_TOPIC: topic is invalid
-    :var NONE: no Error
-    :var UNKNOWN: a unknown error
     """
     BAD_MESSAGE = 'ERR_BADMESSAGE'
     BAD_AUTH = 'ERR_BADAUTH'
@@ -203,9 +134,6 @@ class PubSubResponseError(Enum):
 
 class CustomRewardRedemptionStatus(Enum):
     """
-    :var UNFULFILLED:
-    :var FULFILLED:
-    :var CANCELED:
     """
     UNFULFILLED = 'UNFULFILLED'
     FULFILLED = 'FULFILLED'
@@ -214,8 +142,6 @@ class CustomRewardRedemptionStatus(Enum):
 
 class SortOrder(Enum):
     """
-    :var OLDEST:
-    :var NEWEST:
     """
     OLDEST = 'OLDEST'
     NEWEST = 'NEWEST'
@@ -223,8 +149,6 @@ class SortOrder(Enum):
 
 class BlockSourceContext(Enum):
     """
-    :var CHAT:
-    :var WHISPER:
     """
     CHAT = 'chat'
     WHISPER = 'whisper'
@@ -232,15 +156,58 @@ class BlockSourceContext(Enum):
 
 class BlockReason(Enum):
     """
-    :var SPAM:
-    :var HARASSMENT:
-    :var OTHER:
     """
     SPAM = 'spam'
     HARASSMENT = 'harassment'
     OTHER = 'other'
 
 
+class EntitlementFulfillmentStatus(Enum):
+    """
+    """
+    CLAIMED = 'CLAIMED'
+    FULFILLED = 'FULFILLED'
+
+
+class PollStatus(Enum):
+    """
+    """
+    ACTIVE = 'ACTIVE'
+    COMPLETED = 'COMPLETED'
+    MODERATED = 'MODERATED'
+    INVALID = 'INVALID'
+    TERMINATED = 'TERMINATED',
+    ARCHIVED = 'ARCHIVED'
+
+
+class PredictionStatus(Enum):
+    """
+    """
+    ACTIVE = 'ACTIVE'
+    RESOLVED = 'RESOLVED'
+    CANCELED = 'CANCELED'
+    LOCKED = 'LOCKED'
+
+
+class AutoModAction(Enum):
+    """
+    """
+    ALLOW = 'ALLOW'
+    DENY = 'DENY'
+
+
+class AutoModCheckEntry(TypedDict):
+    msg_id: str
+    """Developer-generated identifier for mapping messages to results."""
+    msg_text: str
+    """Message text"""
+    user_id: str
+    """User ID of the sender"""
+
+
+# EXCEPTIONS
+
+
 class TwitchAPIException(Exception):
     """Base Twitch API Exception"""
     pass
@@ -289,3 +256,23 @@ class PubSubListenTimeoutException(TwitchAPIException):
 class MissingAppSecretException(TwitchAPIException):
     """When the app secret is not set but app authorization is attempted"""
     pass
+
+
+class EventSubSubscriptionTimeout(TwitchAPIException):
+    """When the waiting for a confirmed EventSub subscription timed out"""
+    pass
+
+
+class EventSubSubscriptionConflict(TwitchAPIException):
+    """When you try to subscribe to a EventSub subscription that already exists"""
+    pass
+
+
+class EventSubSubscriptionError(TwitchAPIException):
+    """if the subscription request was invalid"""
+    pass
+
+
+class DeprecatedError(TwitchAPIException):
+    """If something has been marked as deprecated by the Twitch API"""
+    pass
